from setuptools import setup

setup(
    name='kube_app',
    version='0.11',
    packages=['kube_app'],
    license='MIT',
    author='lalit',
    author_email='lalit.krishna@kockpit.in',
    url='https://pypi.org/project/kube-app/'
)
